# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/research/chapter/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/research/chapter/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Research\\Chapter\\": "packages/research/chapter/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Research\Chapter\Providers\ChapterServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Chapter'  => Research\Chapter\Facades\Chapter::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Research\\ChapterTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Research\Chapter\Providers\ChapterServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Research\Chapter\Providers\ChapterServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Research\Chapter\Providers\ChapterServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/chapter/{modulename}

**User**

    http://path-to-route-folder/user/chapter/{modulename}

**Public**

    http://path-to-route-folder/chapters


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/chapter/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/chapter/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/chapter/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/chapter/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/chapter/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/chapter/{modulename}/{slug}
    METHOD: GET